==> js-executor-cg-lib-1.0.10.tgz: package/lib/transforms.js <==

const {log,helpers} = require('utils-nxg-cg');
const vm = require('vm');
const { messages } = require('elasticio-node');
const co = require('co');
const convert = require('xml-js');
const luxon = require('luxon');
const encryp = require('cryptr');
const lodash = require('lodash');
const {utils} = require('utils-limited');

/**
 *
 * @param properties
 * @returns {Promise<Object>}
 */
let finalResult;
function wait(timeout) {
    return new Promise((ok) => {
      setTimeout(() => {
        console.log('Done wait');
        ok();
      }, timeout);
      console.log('Start wait sec=%s', timeout);
    });
  }
  
const transformJsExecutor = async (properties,data) => {
  let arguments = data;
        const vmExports = {};
        const ctx = vm.createContext({
            // Node Globals
            Buffer,
            clearInterval,
            clearTimeout,
            console,
            exports: vmExports,
            global: {},
            module: { exports: vmExports },
            process,
            require,
            setInterval,
            setTimeout,
            URL,
            URLSearchParams,
            arguments,
            // Other Libraries
            convert,
            luxon,
            encryp,
            lodash,
            utils,
            
            wait: wait.bind(this),
        });
        //console.log('my properties '+properties);
        vm.runInContext(properties.code, ctx, {      
            displayErrors: true,
          });

        if (ctx.run && typeof ctx.run.apply === 'function') {
            let result;
            if (ctx.run.constructor.name === 'GeneratorFunction') {
            console.log('Run variable is a generator');
            const fn = co.wrap(ctx.run);
            result = fn.apply(this, [ arguments]);
            } else {
            console.log('Run variable is a function, calling it');
            result = ctx.run.apply(this, [arguments]);
   
            }
            if (typeof result === 'object' && typeof result.then === 'function') {
            console.log('Returned value is a promise, will evaluate it');
            let returnResult;
            try {
                returnResult = await result;
               // console.log('aqui imprimiendo el result ed ale '+returnResult);
               
                return returnResult;
                
            } catch (e) {
                throw Error(e);
            }
            }
        } else {
            return("Run function was not found, it's over now");
          
        }

            
};



module.exports = {transformJsExecutor};

==> js-executor-cg-lib-1.0.13.tgz: package/lib/transforms.js <==

const {log,helpers} = require('utils-nxg-cg');
const vm = require('vm');
const { messages } = require('elasticio-node');
const co = require('co');
const convert = require('xml-js');
const { DateTime } = require('luxon');
const Cryptr  = require('cryptr');
const lodash = require('lodash');
const {utils} = require('utils-limited');

/**
 *
 * @param properties
 * @returns {Promise<Object>}
 */
let finalResult;
function wait(timeout) {
    return new Promise((ok) => {
      setTimeout(() => {
        console.log('Done wait');
        ok();
      }, timeout);
      console.log('Start wait sec=%s', timeout);
    });
  }
  
const transformJsExecutor = async (properties,data) => {
  let arguments = data;
        const vmExports = {};
        const ctx = vm.createContext({
            // Node Globals
            Buffer,
            clearInterval,
            clearTimeout,
            console,
            exports: vmExports,
            global: {},
            module: { exports: vmExports },
            process,
            require,
            setInterval,
            setTimeout,
            URL,
            URLSearchParams,
            arguments,
            // Other Libraries
            convert,
            DateTime,
            Cryptr,
            lodash,
            utils,
            
            wait: wait.bind(this),
        });
        //console.log('my properties '+properties);
        vm.runInContext(properties.code, ctx, {      
            displayErrors: true,
          });

        if (ctx.run && typeof ctx.run.apply === 'function') {
            let result;
            if (ctx.run.constructor.name === 'GeneratorFunction') {

            const fn = co.wrap(ctx.run);
            result = fn.apply(this, [ arguments]);
            } else {
           
            result = ctx.run.apply(this, [arguments]);
   
            }
            if (typeof result === 'object' && typeof result.then === 'function') {
      
            let returnResult;
            try {
                returnResult = await result;
               // console.log('aqui imprimiendo el result ed ale '+returnResult);
                return returnResult;
                
            } catch (e) {
                throw Error(e);
            }
            }
        } else {
            return("Run function was not found, it's over now");
          
        }

            
};



module.exports = {transformJsExecutor};
